rnalysis.filtering.FoldChangeFilter
===================================

.. currentmodule:: rnalysis.filtering

.. autoclass:: FoldChangeFilter

   
   
   
    .. automethod:: __init__
    
    

   
.. autosummary::
    :toctree: .
    
    FoldChangeFilter.biotypes
    FoldChangeFilter.describe
    FoldChangeFilter.difference
    FoldChangeFilter.filter_abs_log2_fold_change
    FoldChangeFilter.filter_biotype
    FoldChangeFilter.filter_by_attribute
    FoldChangeFilter.filter_fold_change_direction
    FoldChangeFilter.filter_percentile
    FoldChangeFilter.filter_top_n
    FoldChangeFilter.head
    FoldChangeFilter.intersection
    FoldChangeFilter.number_filters
    FoldChangeFilter.print_features
    FoldChangeFilter.randomization_test
    FoldChangeFilter.save_csv
    FoldChangeFilter.sort
    FoldChangeFilter.split_by_attribute
    FoldChangeFilter.split_by_percentile
    FoldChangeFilter.split_fold_change_direction
    FoldChangeFilter.symmetric_difference
    FoldChangeFilter.tail
    FoldChangeFilter.text_filters
    FoldChangeFilter.union
    
    